@@ -15,7 +15,11 @@ def main():
         help="config directory that maps to cfg:// root. (default: `cfg`)"
     )
     args, unknown_args = parser.parse_known_args()
-    cfgs = cfgopt.parse_configs(cfg_root=args.cfgdir, args=unknown_args)
+    cfgs = cfgopt.parse_configs(
+        cfg_root=args.cfgdir,
+        args=unknown_args,
+        args_root=args.recipe,
+    )
     _main = cfgs[args.recipe]
     return _main(recursive=False)
 
