@@ -316,7 +316,7 @@ def parse_configs(cfg_root:Union[str, Dict], args=None, args_root=None) -> Confi
 
     # use command line options to update json configs
     def command_line_update(_args):
-        updator_pattern = re.compile("^--(.*)=(.*)")
+        updator_pattern = re.compile("^--(.*?)=(.*)")
         unparsed_args = []
         for updator in _args:
             match_obj = updator_pattern.fullmatch(updator.replace("\n", ""))
@@ -336,7 +336,7 @@ def parse_configs(cfg_root:Union[str, Dict], args=None, args_root=None) -> Confi
                 try:
                     data = json.loads(data)
                 except json.JSONDecodeError as e:
-                    raise ConfigParseError(f"While parsing {data}, {e}.") from None
+                    raise ConfigParseError(f"Invalid JSON while parsing {data}, {e}.") from None
                 router[uri] = data  # this line updates root
         return unparsed_args
         
@@ -373,7 +373,6 @@ def parse_configs(cfg_root:Union[str, Dict], args=None, args_root=None) -> Confi
             if _BSE in data:
                 base:Dict = deepcopy(parse_inheritance(data[_BSE], f"{uri}/{_BSE}"))
                 if not isinstance(base, abc.Mapping):
-                    breakpoint()
                     raise ConfigParseError(f"Unable to inherit the base object since it is not parsed as a dict. The base object is: {repr(base)}\nConfig origin: '{uri}/{_BSE}'")
                 data.pop(_BSE)
                 base.update(data)
@@ -440,6 +439,12 @@ def parse_configs(cfg_root:Union[str, Dict], args=None, args_root=None) -> Confi
     unparsed_args = command_line_update(unparsed_args)
     
     if len(unparsed_args):
+        
+        try:
+            router[args_root]
+        except:
+            raise ConfigParseError(f"args_root {args_root} not found")
+        
         unparsed_args_ = ', '.join(f"'{ua[:ua.find('=')+1]}...'" for ua in unparsed_args)
         
         raise ConfigParseError(
